==> jc-1.4.0.tar.gz: gnu/java/net/protocol/http/Headers__24HeaderEntry.h <==
// class gnu.java.net.protocol.http.Headers$HeaderEntry

// class file dependencies
// @dep_class 2f21ab3ec1806686 gnu_java_net_protocol_http_Headers__24HeaderEntry
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_net_protocol_http_Headers__24HeaderEntry_H_
#define _JC_gnu_java_net_protocol_http_Headers__24HeaderEntry_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map__24Entry$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$sub_refs	_jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$sub_refs;
typedef struct _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$sub_nonrefs	_jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$refs	_jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$refs;
typedef struct _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$nonrefs	_jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$nonrefs;
typedef struct _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$object	_jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$object;

typedef const struct _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$vmethods	_jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$vmethods;
typedef const struct _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$vtable	_jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$vtable;
typedef const struct _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$vtype	_jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$vtype;

// Constructors
extern void _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$method$_init$c19d0177094598c9(_jc_env *, struct _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$object *, struct _jc_object *);

// Virtual methods
extern jboolean _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$method$equals$8a15e0625571c581(_jc_env *, struct _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Object$object *_jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$method$getKey$36389701bfdf0ba9(_jc_env *, struct _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$object *);
extern struct _jc_java_lang_Object$object *_jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$method$getValue$6f8b281a5ffcc94f(_jc_env *, struct _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$object *);
extern jint _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$method$hashCode$53152098849316df(_jc_env *, struct _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$object *);
extern struct _jc_java_lang_Object$object *_jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$method$setValue$ebae6c539663892b(_jc_env *, struct _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$method_info$getKey$36389701bfdf0ba9;
extern _jc_method _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$method_info$getValue$6f8b281a5ffcc94f;
extern _jc_method _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$method_info$hashCode$53152098849316df;
extern _jc_method _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$method_info$setValue$ebae6c539663892b;
extern _jc_method _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Object$object	*(*getKey$36389701bfdf0ba9)(_jc_env *, struct _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$object *);
	struct _jc_java_lang_Object$object	*(*getValue$6f8b281a5ffcc94f)(_jc_env *, struct _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$object *);
	struct _jc_java_lang_Object$object	*(*setValue$ebae6c539663892b)(_jc_env *, struct _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$object *);
};

// Vtable
struct _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$vmethods	gnu_java_net_protocol_http_Headers__24HeaderEntry;
};

// Vtype
struct _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$sub_refs {
	struct _jc_object	*entry;
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$refs {
    _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$sub_refs	gnu_java_net_protocol_http_Headers__24HeaderEntry;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$sub_nonrefs	gnu_java_net_protocol_http_Headers__24HeaderEntry;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$object {
	_jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$vtype	*vtype;
	_jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$vtype _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_http_Headers__24HeaderEntry, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$class_object;

#endif	/* _JC_gnu_java_net_protocol_http_Headers__24HeaderEntry_H_ */

==> jc-1.4.6.tar.gz: gnu/java/net/protocol/http/Headers__24HeaderEntry.h <==
// class gnu.java.net.protocol.http.Headers$HeaderEntry

// class file dependencies
// @dep_class 2f21ab3ec1806686 gnu_java_net_protocol_http_Headers__24HeaderEntry
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_net_protocol_http_Headers__24HeaderEntry_H_
#define _JC_gnu_java_net_protocol_http_Headers__24HeaderEntry_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map__24Entry$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$sub_refs	_jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$sub_refs;
typedef struct _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$sub_nonrefs	_jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$refs	_jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$refs;
typedef struct _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$nonrefs	_jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$nonrefs;
typedef struct _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$object	_jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$object;

typedef const struct _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$vmethods	_jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$vmethods;
typedef const struct _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$vtable	_jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$vtable;
typedef const struct _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$vtype	_jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$vtype;

// Constructors
extern void _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$method$_init$c19d0177094598c9(_jc_env *, struct _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$method$equals$8a15e0625571c581(_jc_env *, struct _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$method$getKey$36389701bfdf0ba9(_jc_env *, struct _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$method$getValue$6f8b281a5ffcc94f(_jc_env *, struct _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$method$hashCode$53152098849316df(_jc_env *, struct _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$method$setValue$ebae6c539663892b(_jc_env *, struct _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$method_info$getKey$36389701bfdf0ba9;
extern _jc_method _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$method_info$getValue$6f8b281a5ffcc94f;
extern _jc_method _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$method_info$hashCode$53152098849316df;
extern _jc_method _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$method_info$setValue$ebae6c539663892b;
extern _jc_method _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*getKey$36389701bfdf0ba9)(_jc_env *, struct _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*getValue$6f8b281a5ffcc94f)(_jc_env *, struct _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*setValue$ebae6c539663892b)(_jc_env *, struct _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$vmethods	gnu_java_net_protocol_http_Headers__24HeaderEntry;
};

// Vtype
struct _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$sub_refs {
	struct _jc_object	*entry;
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$refs {
    _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$sub_refs	gnu_java_net_protocol_http_Headers__24HeaderEntry;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$sub_nonrefs	gnu_java_net_protocol_http_Headers__24HeaderEntry;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$object {
	_jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$vtype	*vtype;
	_jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$vtype _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_http_Headers__24HeaderEntry, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_http_Headers__24HeaderEntry$class_object;

#endif	/* _JC_gnu_java_net_protocol_http_Headers__24HeaderEntry_H_ */
